"names.gp" <-
function(x,...){
  # print out names of object components
  ls(envir=x)
}

